%global apiver 1.0

%bcond_without maintainer_mode
%bcond_with doc_pdf

Summary:        C++ API for the cairo graphics library
Name:           cairomm
Version:        1.14.4
Release:        5%{?dist}
License:        LGPL-2.0-or-later
URL:            https://www.cairographics.org
Source0:        https://www.cairographics.org/releases/cairomm-%{version}.tar.xz
BuildRequires:  gcc-c++ meson
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(sigc++-2.0) pkgconfig(fontconfig)
BuildRequires:  pkgconfig(cairo-ft) pkgconfig(cairo-pdf)
BuildRequires:  pkgconfig(cairo-png) pkgconfig(cairo-ps)
BuildRequires:  pkgconfig(cairo-svg) pkgconfig(cairo-xlib)
BuildRequires:  pkgconfig(cairo-xlib-xrender)
BuildRequires:  doxygen graphviz libxslt
BuildRequires:  pkgconfig(mm-common-libstdc++)
BuildRequires:  boost-devel

%if %{with maintainer_mode}
BuildRequires:  mm-common >= 1.0.4
%endif

%if %{with doc_pdf}
BuildRequires:  doxygen-latex make
%endif
Provides:       cairomm%{apiver} = %{version}-%{release}

%description
This library provides a C++ interface to cairo.

The API/ABI version series is %{apiver}.

%package        devel
Summary:        Development files for cairomm
Requires:       cairomm = %{version}-%{release}
Provides:       cairomm%{apiver}-devel = %{version}-%{release}

%description    devel
The cairomm-devel package contains libraries and header files for developing
applications that use cairomm.

The API/ABI version series is %{apiver}.

%package        doc
Summary:        Documentation for cairomm
Provides:       cairomm%{apiver}-doc = %{version}-%{release}
BuildArch:      noarch

%description    doc
Documentation for cairomm can be viewed through the devhelp documentation
browser.

The API/ABI version series is %{apiver}.

%prep
%autosetup
chmod -v a-x NEWS

rm -rf untracked/docs/reference/html
rm untracked/docs/reference/cairomm-%{apiver}.tag \
   untracked/docs/reference/cairomm-%{apiver}.devhelp2
%if %{with doc_pdf}
sed -r -i \
    -e "s/^([[:blank:]]*(GENERATE_LATEX|LATEX_BATCHMODE|USE_PDFLATEX|\
PDF_HYPERLINKS)[[:blank:]]*=[[:blank:]]*)NO[[:blank:]]*/\1YES/" \
    -e "s/^([[:blank:]]*(LATEX_TIMESTAMP)\
[[:blank:]]*=[[:blank:]]*)YES[[:blank:]]*/\1NO/" \
    docs/reference/Doxyfile.in
%endif

%build
%meson \
  -Dmaintainer-mode=%{?with_maintainer_mode:true}%{?!with_maintainer_mode:false} \
  -Dbuild-documentation=true \
  -Dbuild-examples=false \
  -Dbuild-tests=true \
  -Dboost-shared=true \
  -Dwarnings=max
%meson_build

%if %{with doc_pdf}
%make_build -C '%{_vpath_builddir}/docs/reference/latex'
%endif

%install
%meson_install

install -t %{buildroot}%{_docdir}/cairomm-%{apiver} -m 0644 -p \
    AUTHORS ChangeLog MAINTAINERS NEWS README.md
cp -rp examples %{buildroot}%{_docdir}/cairomm-%{apiver}/

find '%{buildroot}%{_docdir}/cairomm-%{apiver}/reference/html' \
    -type f \( -name '*.js' -o -name '*.js.*' \) -print -delete

%if %{with doc_pdf}
install '%{_vpath_builddir}/docs/reference/latex/refman.pdf' -p -m 0644 \
    '%{buildroot}%{_docdir}/cairomm-%{apiver}/reference/cairomm-%{apiver}.pdf'
%endif

%check
%meson_test

%files
%license COPYING
%{_libdir}/libcairomm-%{apiver}.so.1
%{_libdir}/libcairomm-%{apiver}.so.1.*

%files devel
%{_includedir}/cairomm-%{apiver}
%{_libdir}/libcairomm-%{apiver}.so
%{_libdir}/pkgconfig/cairomm-%{apiver}.pc
%{_libdir}/pkgconfig/cairomm-*-%{apiver}.pc
%{_libdir}/cairomm-%{apiver}

%files doc
%license COPYING
%doc %{_docdir}/cairomm-%{apiver}
%doc %{_datadir}/devhelp/

%changelog
* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.14.4-5
- Rebuilt for OpenCloudOS Stream 23.09

* Mon Jul 31 2023 rockerzhu rockerzhu@tencent.com - 1.14.4-4
- Rebuilt for boost 1.82.0

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.14.4-3
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.14.4-2
- Rebuilt for OpenCloudOS Stream 23

* Thu Mar 09 2023 Xiaojie Chen <jackxjchen@tencent.com> - 1.14.4-1
- Initial build
